@@ -25,6 +25,7 @@ SOFTWARE.
 # Imports
 # Files
 import disspy.activity
+import disspy.abstract
 import disspy.application_commands
 import disspy.channel
 import disspy.client
@@ -32,13 +33,15 @@ import disspy.core
 import disspy.embed
 import disspy.errors
 import disspy.guild
-import disspy.logger
-import disspy.message
 import disspy.user
 import disspy.reaction
 import disspy.ui
 
 # Classes
+from disspy.abstract import (
+    Channel,
+    Message
+)
 from disspy.activity import (
     Activity,
     ActivityType
@@ -56,7 +59,11 @@ from disspy.application_commands import (
 )
 from disspy.channel import (
     DisChannel,
-    DisDmChannel
+    DisDmChannel,
+    DisMessage,
+    DmMessage,
+    MessageDeleteEvent,
+    DmMessageDeleteEvent
 )
 from disspy.client import (
     DisBot,
@@ -76,13 +83,6 @@ from disspy.embed import (
 )
 
 from disspy.guild import DisGuild
-from disspy.logger import Logger
-from disspy.message import (
-    DisMessage,
-    DmMessage,
-    MessageDeleteEvent,
-    DmMessageDeleteEvent
-)
 from disspy.user import DisUser
 from disspy.reaction import (
     DisEmoji,
@@ -118,7 +118,7 @@ def _all_generator(alls: list) -> tuple:
 # Variables
 
 # Version of disspy
-__version__ = "0.5.3.3"
+__version__ = "0.5.4"
 
 # Link to GitHub repo
 __github__ = "https://github.com/itttgg/dispy"
@@ -136,6 +136,7 @@ __packagename__ = "dispy"
 # __all__
 __alls__: list = [
     disspy.activity.__all__,
+    disspy.abstract.__all__,
     disspy.application_commands.__all__,
     disspy.channel.__all__,
     disspy.client.__all__,
@@ -143,8 +144,6 @@ __alls__: list = [
     disspy.embed.__all__,
     disspy.errors.__all__,
     disspy.guild.__all__,
-    disspy.logger.__all__,
-    disspy.message.__all__,
     disspy.user.__all__,
     disspy.reaction.__all__,
     disspy.ui.__all__
