@@ -82,16 +82,15 @@ class _SendingRestHandler:
         Returns:
             _type_: _description_
         """
-        async with aiohttp.ClientSession(headers={'Authorization': f'Bot {token}', 'content-type': 'application/json'}) as s:
-            await s.post(url, data=dumps(payload))
+        async with aiohttp.ClientSession(headers={'Authorization': f'Bot {token}',
+                                                  'content-type': 'application/json'}) as session:
             try:
-                async with s.post(url, data=dumps(payload)) as d:
-                    j = await d.json()
+                async with session.post(url, data=dumps(payload)) as data:
+                    j = await data.json()
 
                     return j
             except aiohttp.ContentTypeError:
-                await s.post(url, data=dumps(payload))
-                return None
+                await session.post(url, data=dumps(payload))
 
 
 @final
@@ -179,8 +178,8 @@ class SlashCommand(ApplicationCommand):
         if options:
             _options_jsons = []
 
-            for o in options:
-                _options_jsons.append(_OptionGenerator(o))
+            for option in options:
+                _options_jsons.append(_OptionGenerator(option))
 
             self.options: Union[List[Option], None] = _options_jsons
         else:
@@ -267,8 +266,10 @@ class Context:
                     }
                 }
 
-        _url = "https://discord.com/api/v10/interactions/{0}/{1}/callback".format(
-            self._interaction_id, self._interaction_token)
+        _id = self._interaction_id
+        _token = self._interaction_token
+
+        _url = f"https://discord.com/api/v10/interactions/{_id}/{_token}/callback"
 
         await _SendingRestHandler.execute(_url, _payload, self._t)
 
@@ -289,8 +290,10 @@ class Context:
             }
         }
 
-        _url = "https://discord.com/api/v10/interactions/{0}/{1}/callback".format(
-            self._interaction_id, self._interaction_token)
+        _id = self._interaction_id
+        _token = self._interaction_token
+
+        _url = f"https://discord.com/api/v10/interactions/{_id}/{_token}/callback"
 
         await _SendingRestHandler.execute(_url, _payload, self._t)
 
@@ -327,62 +330,67 @@ class OptionArgs:
     def isempty(self) -> bool:
         """
         Returns True or False when is empty is True or False
-        -----
+
         :return bool: Is empty?
         """
         return len(self._v) == 0
 
-    def get(self, name: str) -> Any:
+    def get(self, name: str) -> Union[Any, None]:
         """
         Get value from name
-        -----
+
         :param name: Name of option
         :return Any: Option value
         """
-        for a in self._v:
-            if a.name == name:
-                return a.value
+        for _a in self._v:
+            if _a.name == name:
+                return _a.value
+        return None
 
-    def getString(self, name: str) -> str:
+    def get_string(self, name: str) -> Union[str, None]:
         """
         Get string value from name
-        -----
+
         :param name: Name of option
         :return str: Option value (always string)
         """
-        for a in self._v:
-            if a.name == name and a.type == OptionType.STRING:
-                return str(a.value)
+        for _a in self._v:
+            if _a.name == name and _a.type == OptionType.STRING:
+                return str(_a.value)
+        return None
 
-    def getInteger(self, name: str) -> int:
+    def get_integer(self, name: str) -> Union[int, None]:
         """
         Get integer value from na1me
-        -----
+
         :param name: Name of option
         :return int: Option value (always integer)
         """
-        for a in self._v:
-            if a.name == name and a.type == OptionType.INTEGER:
-                return int(a.value)
+        for _a in self._v:
+            if _a.name == name and _a.type == OptionType.INTEGER:
+                return int(_a.value)
+        return None
 
-    def getNumber(self, name: str) -> int:
+    def get_number(self, name: str) -> Union[int, None]:
         """
         Get number value from name
-        -----
+
         :param name: Name of option
         :return int: Option value (always integer)
         """
-        for a in self._v:
-            if a.name == name and a.type == OptionType.NUMBER:
-                return int(a.value)
+        for _a in self._v:
+            if _a.name == name and _a.type == OptionType.NUMBER:
+                return int(_a.value)
+        return None
 
-    def getBoolean(self, name: str) -> bool:
+    def get_boolean(self, name: str) -> Union[bool, None]:
         """
         Get boolean value from name
-        -----
+
         :param name: Name of option
         :return bool: Option value (always boolean)
         """
-        for a in self._v:
-            if a.name == name and a.type == OptionType.BOOLEAN:
-                return bool(a.value)
+        for _a in self._v:
+            if _a.name == name and _a.type == OptionType.BOOLEAN:
+                return bool(_a.value)
+        return None
