@@ -40,6 +40,8 @@ from typing import (
     Generic,
     final
 )
+
+from enum import Enum, auto
 from datetime import datetime
 from time import mktime
 from aiohttp import ClientSession
@@ -48,15 +50,16 @@ import colorama
 
 
 # disspy imports
-from disspy.channel import DisChannel, DisDmChannel
-from disspy.errors import ClassTypeError
-from disspy.guild import DisGuild
-from disspy.message import (
+from disspy.channel import (
+    DisChannel,
+    DisDmChannel,
     DisMessage,
     DmMessage,
     MessageDeleteEvent,
     DmMessageDeleteEvent
 )
+from disspy.errors import ClassTypeError
+from disspy.guild import DisGuild
 from disspy.reaction import DisEmoji, DisReaction, DisRemovedReaction
 from disspy.user import DisUser
 from disspy.application_commands import Context, _Argument, OptionArgs
@@ -147,7 +150,14 @@ class _DebugLoggingWebsocket:
         except KeyError:
             _op = 0
 
-        _result = ""
+        _datetime = datetime.now()
+
+        _second = _datetime.second if _datetime.second > 9 else f"{_datetime.second}0"
+
+        _date = f"{_datetime.day}/{_datetime.month}/{_datetime.year}"
+        _time = f"{_datetime.hour}:{_datetime.minute}:{_second}.{str(_datetime.microsecond)[:2]}"
+
+        _result = f"{colorama.Fore.CYAN}[{_date}: {_time}]{colorama.Fore.RESET} "
 
         _op_str = FlowOpcodes.rotated_dict()[_op]
         _op_str = _op_str.capitalize()
@@ -168,25 +178,36 @@ class _DebugLoggingWebsocket:
             if _op == 11:
                 _op_str = "Heartbeat ACK"
 
-            _result = f"{colorama.Fore.GREEN}Sending Request{colorama.Fore.RED}{_2part}"
+            _result += f"{colorama.Fore.GREEN}Sending Request{colorama.Fore.RED}"
         else:
             if _isevent:
                 if _op == 11:
                     _op_str = "Heartbeat ACK"
 
-                _result = f"{colorama.Fore.YELLOW}Getting Event{colorama.Fore.RED}{_2part}"
+                _result += f"{colorama.Fore.YELLOW}Getting Event{colorama.Fore.RED}"
             else:
                 if _op == 11:
                     _op_str = "Heartbeat ACK"
 
-                _result = f"{colorama.Fore.YELLOW}Getting Responce{colorama.Fore.RED}{_2part}"
+                _result += f"{colorama.Fore.YELLOW}Getting Responce{colorama.Fore.RED}"
+
+        _result += _2part
 
         return _result
 
 
 class _DebugLoggingAwaiting:
     def __new__(cls, gateway_event_name, event_name):
-        _result = f'{colorama.Fore.RED}Awaiting event "{gateway_event_name}": '
+        _datetime = datetime.now()
+
+        _second = _datetime.second if _datetime.second > 9 else f"{_datetime.second}0"
+
+        _date = f"{_datetime.day}/{_datetime.month}/{_datetime.year}"
+        _time = f"{_datetime.hour}:{_datetime.minute}:{_second}.{str(_datetime.microsecond)[:2]}"
+
+        _result = f"{colorama.Fore.CYAN}[{_date}: {_time}]{colorama.Fore.RESET} "
+
+        _result += f'{colorama.Fore.RED}Awaiting event "{gateway_event_name}": '
         _result += f'{colorama.Fore.YELLOW}{event_name}(){colorama.Fore.RESET}'
 
         return _result
@@ -271,6 +292,30 @@ class _FlowEvent:
             }
 
 
+class _AutoFlags(Enum):
+    def _generate_next_value_(name, start, count, last_values):
+        return 1 << count
+
+class _Intents(_AutoFlags):
+    GUILDS = auto()
+    GUILD_MEMBERS = auto()
+    GUILD_BANS = auto()
+    GUILD_EMOJIS_AND_STICKERS = auto()
+    GUILD_INTEGRATIONS = auto()
+    GUILD_WEBHOOKS = auto()
+    GUILD_INVITES = auto()
+    GUILD_VOICE_STATES = auto()
+    GUILD_PRESENCES = auto()
+    GUILD_MESSAGES = auto()
+    GUILD_MESSAGE_REACTIONS = auto()
+    GUILD_MESSAGE_TYPING = auto()
+    DIRECT_MESSAGES = auto()
+    DIRECT_MESSAGE_REACTIONS = auto()
+    DIRECT_MESSAGE_TYPING  = auto()
+    MESSAGE_CONTENT = auto()
+    GUILD_SCHEDULED_EVENTS = auto()
+
+
 class DisFlags:
     """
     The class for using intents in bots
@@ -294,7 +339,7 @@ class DisFlags:
 
         :return int: integer value of intents
         """
-        return 0
+        return int(_Intents.GUILD_INTEGRATIONS.value)
 
     @staticmethod
     def messages() -> int:
@@ -308,7 +353,12 @@ class DisFlags:
 
         :return int: integer value of intents
         """
-        return 55808
+
+        _typings = _Intents.GUILD_MESSAGE_TYPING.value + _Intents.DIRECT_MESSAGE_TYPING.value
+        _messages = _Intents.GUILD_MESSAGES.value + _Intents.DIRECT_MESSAGES.value
+        _content = _Intents.MESSAGE_CONTENT.value
+
+        return int(_Intents.GUILD_INTEGRATIONS.value + _typings + _messages + _content)
 
     @staticmethod
     def reactions() -> int:
@@ -319,7 +369,10 @@ class DisFlags:
 
         :return int: integer value of intents
         """
-        return 9216
+        _dm_reactions = _Intents.DIRECT_MESSAGE_REACTIONS.value
+        _reactions = _Intents.GUILD_MESSAGE_REACTIONS.value + _dm_reactions
+
+        return int(_Intents.GUILD_INTEGRATIONS.value + _reactions)
 
     @staticmethod
     def all() -> int:
@@ -345,7 +398,12 @@ class DisFlags:
 
         :return int: integer value of intents
         """
-        return 3276799
+        result = 0
+
+        for i in _Intents:
+            result += i.value
+
+        return int(result)
 
 
 T = TypeVar("T", str, int)
@@ -378,14 +436,14 @@ class Snowflake(Generic[T]):
     def __int__(self) -> int:
         if not self.isid:
             raise ClassTypeError("Class Value is str, but this method needs for int!")
-        else:
-            return int(self.value)
+
+        return int(self.value)
 
     def __str__(self) -> str:
         if not self.istoken:
             raise ClassTypeError("Class Value is int, but this method needs for str!")
-        else:
-            return str(self.value)
+
+        return str(self.value)
 
 
 ChannelId = NewType("ChannelId", int)
@@ -405,7 +463,7 @@ class Rest:
 
         self.__slots__ = [self._headers]
 
-    def get(self, goal: str, goal_id: Union[int, Snowflake]) -> JsonOutput:
+    def get(self, goal: str, goal_id: Union[int, Snowflake]) -> Union[JsonOutput, None]:
         """
         :param goal: guild/channel/user
         :param id: id of guild/channel/user
@@ -418,18 +476,20 @@ class Rest:
             return get(url=_url,
                        headers=self._headers).json()
 
-        elif goal.casefold() == 'channel':
+        if goal.casefold() == 'channel':
             _url = f'{_mainurl()}channels/{str(goal_id)}'
 
             return get(url=_url,
                        headers=self._headers).json()
 
-        elif goal.casefold() == "user":
+        if goal.casefold() == "user":
             _url = f'{_mainurl()}users/{str(goal_id)}'
 
             return get(url=_url,
                        headers=self._headers).json()
 
+        return None
+
     def fetch(self, channel_id, message_id) -> JsonOutput:
         """fetch()
 
@@ -494,7 +554,7 @@ class Flow:
 
         self._headers = {}
 
-        self.ws = None
+        self.websocket = None
         self.ons = None
 
     # Event methods
@@ -505,7 +565,7 @@ class Flow:
         Args:
             message (DisMessage): Message that was created
         """
-        return message.content
+        return message.content  # For PyLint
 
     async def register(self, data):
         """register
@@ -517,7 +577,7 @@ class Flow:
         self.user_id = data["user"]["id"]
 
     # Sending/Getting
-    async def send_request(self, data, ws):
+    async def send_request(self, data, websocket):
         """send_request
         Send json request to Gateway
 
@@ -528,14 +588,14 @@ class Flow:
         Returns:
             dict: Your json data
         """
-        await ws.send_json(data)
+        await websocket.send_json(data)
 
         if self._debug:
             print(_DebugLoggingWebsocket(data, send=True, isevent=False, op=data["op"]))
 
         return data
 
-    async def get_responce(self, ws):
+    async def get_responce(self, websocket):
         """get_responce
         Get json output from Gateway
 
@@ -546,7 +606,7 @@ class Flow:
             dict: Json output
         """
         try:
-            j = await ws.receive_json()
+            j = await websocket.receive_json()
         except TypeError:
             return
 
@@ -586,17 +646,15 @@ class Flow:
         self.isrunning = True
         self.isafk = False
 
-        self.ws = None
-
         await self._runner()
 
     async def _runner(self):
         async with ClientSession() as session:
             async with session.ws_connect(
-                f"wss://gateway.discord.gg/?v={self.gateway_version}&encoding=json") as ws:
-                self.ws = ws
+                f"wss://gateway.discord.gg/?v={self.gateway_version}&encoding=json") as websocket:
+                self.websocket = websocket
 
-                j = await self.get_responce(ws)
+                j = await self.get_responce(websocket)
 
                 interval = j["d"]["heartbeat_interval"]
 
@@ -615,29 +673,30 @@ class Flow:
                         "status": self.status,
                         "activities": [self.activity]
                     }
-                }}, ws)
+                }}, websocket)
 
                 self.isrunning = True
 
                 await asyncio.wait(
-                    fs=[self.heartbeat(ws, interval / 1000), self._events_checker(ws)])
+                    fs=[self.heartbeat(websocket, interval / 1000),
+                        self._events_checker(websocket)])  # Run Gateway client
 
-    async def heartbeat(self, ws, interval):
+    async def heartbeat(self, websocket, interval):
         """heartbeat
         Function with sending heartbeating to Gateway
 
         Args:
-            ws (Any): Aiohttp websocket
+            websocket (Any): Aiohttp websocket
             interval (int): Heartbeat interval
         """
         while True:
-            await self.send_request({"op": 1, "d": None, "t": None}, ws)
+            await self.send_request({"op": 1, "d": None, "t": None}, websocket)
 
             await asyncio.sleep(interval)
 
-    async def _events_checker(self, ws):
+    async def _events_checker(self, websocket):
         while True:
-            event_json = await self.get_responce(ws)
+            event_json = await self.get_responce(websocket)
             event = _FlowEvent(event_json)
 
             try:
@@ -843,7 +902,7 @@ class Flow:
         """disconnecter
         Disconnect from Gateway
         """
-        await self.ws.close()
+        await self.websocket.close()
 
 
 @final
@@ -949,61 +1008,58 @@ class DisApi(_RequestsUserClass):
 
     async def _on_interaction(self, token, interaction_id, command_name, bot_token: str,
                               interaction_type, data: JsonOutput, type_of_command=None) -> NoReturn:
-        if type_of_command is None:
-            return
-        else:
-            if interaction_type == 2:
-                _ctx = Context(token, interaction_id, bot_token)
+        if interaction_type == 2:
+            _ctx = Context(token, interaction_id, bot_token)
 
-                try:
-                    if type_of_command == 3:  # Message Commands
-                        resolved: dict = data["data"]["resolved"]["messages"]
+            try:
+                if type_of_command == 3:  # Message Commands
+                    resolved: dict = data["data"]["resolved"]["messages"]
 
-                        _m_id = list(resolved.keys())[0]
-                        _m_d: dict = resolved[_m_id]
+                    _m_id = list(resolved.keys())[0]
+                    _m_d: dict = resolved[_m_id]
 
-                        try:
-                            _m_d["id"] = _m_id
-                        except KeyError:
-                            _m_d.setdefault("id", _m_id)
+                    try:
+                        _m_d["id"] = _m_id
+                    except KeyError:
+                        _m_d.setdefault("id", _m_id)
 
-                        _m = DisMessage(_m_d, self.token)
+                    _m = DisMessage(_m_d, self.token)
 
-                        await self.app_commands[type_of_command - 1][command_name](_ctx, _m)
+                    await self.app_commands[type_of_command - 1][command_name](_ctx, _m)
 
-                    elif type_of_command == 2:  # User Commands
-                        resolved: dict = data["data"]["resolved"]["users"]
+                elif type_of_command == 2:  # User Commands
+                    resolved: dict = data["data"]["resolved"]["users"]
 
-                        _u_id = list(resolved.keys())[0]
-                        _u_d: dict = resolved[_u_id]
+                    _u_id = list(resolved.keys())[0]
+                    _u_d: dict = resolved[_u_id]
 
-                        try:
-                            _u_d["id"] = _u_id
-                        except KeyError:
-                            _u_d.setdefault("id", _u_id)
+                    try:
+                        _u_d["id"] = _u_id
+                    except KeyError:
+                        _u_d.setdefault("id", _u_id)
 
-                        _u = DisUser(_u_d, self.token)
+                    _u = DisUser(_u_d, self.token)
 
-                        await self.app_commands[type_of_command - 1][command_name](_ctx, _u)
+                    await self.app_commands[type_of_command - 1][command_name](_ctx, _u)
 
-                    elif type_of_command == 1:  # Slash Commands
+                elif type_of_command == 1:  # Slash Commands
+                    _args = []
+
+                    try:
+                        for option in data["data"]["options"]:
+                            _args.append(_Argument(option["name"],
+                                                    option["type"],
+                                                    option["value"]))
+                    except KeyError:
                         _args = []
 
-                        try:
-                            for option in data["data"]["options"]:
-                                _args.append(_Argument(option["name"],
-                                                       option["type"],
-                                                       option["value"]))
-                        except KeyError:
-                            _args = []
+                    func = self.app_commands[type_of_command - 1][command_name]
 
-                        func = self.app_commands[type_of_command - 1][command_name]
-
-                        await func(_ctx, OptionArgs(_args))
-                    else:
-                        pass
-                except KeyError:
+                    await func(_ctx, OptionArgs(_args))
+                else:
                     pass
+            except KeyError:
+                pass
 
     async def _on_components(self, data):
         if data["data"]["component_type"] == 2:
@@ -1143,4 +1199,4 @@ class DisApi(_RequestsUserClass):
         Args:
             data (dict): Json data for sending request
         """
-        await self.flow.send_request(data, self.flow.ws)
+        await self.flow.send_request(data, self.flow.websocket)
